.leaflet-label {
    background: #fff;
    background-clip: padding-box;
    border: solid 4px #111;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
    color: #111;
    display: block;
    position: absolute;
    -webkit-user-select: none;
       -moz-user-select: none;
        -ms-user-select: none;
            user-select: none;
    pointer-events: none;
    white-space: nowrap;
    z-index: 6;
    font-size: 12px;
    line-height: 1.4em;
    font-weight: bold;
    padding: 1px 6px;
}

.leaflet-label.leaflet-clickable {
    cursor: pointer;
}

.leaflet-label:before,
.leaflet-label:after {
    border-top: 6px solid transparent;
    border-bottom: 6px solid transparent;
    content: none;
    position: absolute;
    top: 5px;
}

.leaflet-label:before {
    border-right: 6px solid black;
    border-right-color: inherit;
    left: -10px;
}

.leaflet-label:after {
    border-left: 6px solid black;
    border-left-color: inherit;
    right: -10px;
}

.leaflet-label-right:before,
.leaflet-label-left:after {
    content: "";
}