<section class="clearfix hidden header-container" id="query-topic-picker">
    <h1>Find a table</h1>
    <div class="typeahead-container">
        <input name="topic_select" id="topic-select" type="text" placeholder="Search by table or column name..." autocomplete="off">
        <p class="explain"><a href="#" id="cancel-search">Cancel search</a></p>
    </div>
</section>
